==> synapselabels-4.4.1-py3-none-any.whl: synapselabels/imgconverter.py <==
# -*- coding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function


# from PIL import Image
import traceback
import tempfile
# import sys
from sys import stdout
from time import time
from os import remove
from os.path import isfile
from subprocess import Popen
# from subprocess import PIPE
# from subprocess import STDOUT
from pexpect import popen_spawn
from .utils import svg_dir


class InkscapeShell():
    """TBD make it more fail safe: restart process if closed"""

    def __init__(self):
        args = [
            'inkscape',
            '--shell',
            ]
        self.proc = popen_spawn.PopenSpawn(
            ' '.join(args), cwd=svg_dir,  # encoding="utf-8",
            )
        # self.proc = Popen(
        #     args, stdout=PIPE, stdin=PIPE, stderr=STDOUT, cwd=svg_dir
        #     )
        self.proc.expect('>')
        print(self.proc.before)

    def export_svg_to_png(self, input_file, output_file=None):
        assert(input_file.endswith('.svg'))
        if output_file is None:
            output_file = input_file[:-3] + 'png'
        # This method did not work on Windows
        # args = [
        #     '-z',
        #     '-f', input_file,
        #     '-e', output_file,
        #     '--export-dpi=300',
        #     '--export-area-page',
        #     ]
        # command = ' '.join(args)
        command = (
            '-z -f "%s" -e "%s" --export-dpi=300 --export-area-page' %
            (input_file, output_file)
            )
        print('command:', command)
        self.timed_command(command)

    def timed_command(self, command):
        start_time = time()
        self.proc.write(command + '\n')
        self.proc.expect('>')
        print(self.proc.before)
        print('call completed in %.3f seconds' % (time() - start_time))


inkscape_shell = InkscapeShell()


class ReturnValueError(Exception):
    pass


class CallTimedOutError(Exception):
    pass


def timed_check_call(
    args, cwd=None, timeout=None, shell=False, expected_returncode=0
        ):
    try:
        print('calling:', args)
        start_time = time()
        if shell is True:
            p = Popen(' '.join(args), cwd=cwd, shell=True)
        else:
            p = Popen(args, cwd=cwd, shell=True)
        if timeout is None:
            p.wait()
        else:
            while True:
                if p.poll() is not None:
                    break
                if (time() - start_time) > timeout:
                    p.terminate()
                    raise CallTimedOutError(
                        'call timed out in %.3f seconds' %
                        (time() - start_time)
                        )
        if expected_returncode is not None:
            if p.returncode != expected_returncode:
                raise ReturnValueError(
                    'returncode: %s, expected: %s' % (
                        str(p.returncode),
                        str(expected_returncode)
                        )
                    )
        print('call completed in %.3f seconds' % (time() - start_time))
        return True
    except Exception:
        print('call failed in %.3f seconds' % (time() - start_time))
        traceback.print_exc(file=stdout)


def convert_png_to_bmp(input_file, output_file=None):
    assert(input_file.endswith('.png'))
    if output_file is None:
        output_file = input_file[:-3] + 'bmp'
    print('input_file:', input_file, 'output_file:', output_file)
    args = [
        'magick',
        input_file,
        '-background', 'white',
        '-flatten',
        '-colors', '2',
        '-monochrome',
        '-threshold', '5%',
        output_file,
        ]
    try:
        timed_check_call(args, timeout=10)
    except OSError:
        args[0] = 'convert'
        timed_check_call(args, timeout=10)


"""
def convert_png_to_bmp_2(input_file, output_file=None):
    assert(input_file.endswith('.png'))
    if output_file is None:
        output_file = input_file[:-3] + 'bmp'
    print('input_file:', input_file, 'output_file:', output_file)
    image = Image.open(input_file)
    x_size, y_size = image.size
    bg = Image.new("L", image.size, (255, 255, 255))
    bg.paste(image, image)
    bg1 = bg.quantize(2, method=2)
    bg1.save(output_file, compresssion="bmp_rle")
"""


def export_svg_to_png(input_file, output_file=None):
    inkscape_shell.export_svg_to_png(input_file, output_file)
    # assert(input_file.endswith('.svg'))
    # if output_file is None:
    #     output_file = input_file[:-3] + 'png'
    # args = [
    #     'inkscape',
    #     '-z',
    #     '-f', input_file,
    #     '-e', output_file,
    #     '--export-dpi=300',
    #     '--export-area-page',
    #     ]
    # timed_check_call(args, cwd=svg_dir, timeout=15)


def export_svg_to_bmp(svg_file, bmp_file=None):
    assert(svg_file.endswith('.svg'))
    if bmp_file is None:
        bmp_file = svg_file[:-3] + 'bmp'
    with tempfile.NamedTemporaryFile(
        prefix='',
        suffix='.png',
        delete=False
            ) as temp_file:
        png_file = temp_file.name
    try:
        export_svg_to_png(svg_file, png_file)
        convert_png_to_bmp(png_file, bmp_file)
    finally:
        if isfile(png_file):
            try:
                remove(png_file)
            except Exception:
                print('cannot remove temporary file:', png_file)
                traceback.print_exc(file=stdout)

==> synapselabels-4.8.0-py3-none-any.whl: synapselabels/imgconverter.py <==
# -*- coding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function


# from PIL import Image
import traceback
import tempfile
import sys
from sys import stdout
from time import time
from os import remove
from os.path import isfile
from subprocess import Popen
# from subprocess import PIPE
# from subprocess import STDOUT
from pexpect import popen_spawn
from .utils import svg_dir


class InkscapeShell():
    """TBD make it more fail safe: restart process if closed"""

    def __init__(self):
        args = [
            'inkscape',
            '--shell',
        ]
        self.proc = popen_spawn.PopenSpawn(
            ' '.join(args), cwd=svg_dir,  # encoding="utf-8",
        )
        # self.proc = Popen(
        #     args, stdout=PIPE, stdin=PIPE, stderr=STDOUT, cwd=svg_dir
        #     )
        self.proc.expect('>')
        print(self.proc.before)

    def export_svg_to_png(self, input_file, output_file=None):
        assert input_file.endswith('.svg')
        if output_file is None:
            output_file = input_file[:-3] + 'png'
        # This method did not work on Windows
        # args = [
        #     '-z',
        #     '-f', input_file,
        #     '-e', output_file,
        #     '--export-dpi=300',
        #     '--export-area-page',
        #     ]
        # command = ' '.join(args)
        command = (
            '-z -f "%s" -e "%s" --export-dpi=300 --export-area-page' %
            (input_file, output_file)
        )
        print('command:', command)
        self.timed_command(command)

    def timed_command(self, command):
        start_time = time()
        self.proc.write(command + '\n')
        self.proc.expect('>')
        print(self.proc.before)
        print('call completed in %.3f seconds' % (time() - start_time))


inkscape_shell = None


class ReturnValueError(Exception):
    pass


class CallTimedOutError(Exception):
    pass


def timed_check_call(
        args, cwd=None, timeout=None, shell=False, expected_returncode=0
):
    try:
        print('calling:', args)
        start_time = time()
        if shell is True:
            p = Popen(' '.join(args), cwd=cwd, shell=True)
        else:
            p = Popen(args, cwd=cwd)
        if timeout is None:
            p.wait()
        else:
            while True:
                if p.poll() is not None:
                    break
                if (time() - start_time) > timeout:
                    p.terminate()
                    raise CallTimedOutError(
                        'call timed out in %.3f seconds' %
                        (time() - start_time)
                    )
        if expected_returncode is not None:
            if p.returncode != expected_returncode:
                raise ReturnValueError(
                    'returncode: %s, expected: %s' % (
                        str(p.returncode),
                        str(expected_returncode)
                    )
                )
        print('call completed in %.3f seconds' % (time() - start_time))
        return True
    except (OSError, CallTimedOutError, ReturnValueError):
        print('call failed in %.3f seconds' % (time() - start_time))
        # traceback.print_exc(file=stdout)
        raise


def convert_png_to_bmp(input_file, output_file=None):
    assert input_file.endswith('.png')
    if output_file is None:
        output_file = input_file[:-3] + 'bmp'
    print('input_file:', input_file, 'output_file:', output_file)
    args = [
        'magick',
        input_file,
        '-background', 'white',
        '-flatten',
        '-colors', '2',
        '-monochrome',
        '-threshold', '5%',
        output_file,
    ]
    try:
        print('calling %s command...' % args[0])
        timed_check_call(args, timeout=10)
    except (OSError, CallTimedOutError, ReturnValueError):
        args[0] = 'convert'
        print('calling %s command...' % args[0])
        timed_check_call(args, timeout=10)


def main_png_to_bmp():
    print('main')
    if len(sys.argv) > 1:
        if len(sys.argv) > 2:
            convert_png_to_bmp(sys.argv[1], sys.argv[2])
        else:
            convert_png_to_bmp(sys.argv[1])


"""
def convert_png_to_bmp_2(input_file, output_file=None):
    assert(input_file.endswith('.png'))
    if output_file is None:
        output_file = input_file[:-3] + 'bmp'
    print('input_file:', input_file, 'output_file:', output_file)
    image = Image.open(input_file)
    x_size, y_size = image.size
    bg = Image.new("L", image.size, (255, 255, 255))
    bg.paste(image, image)
    bg1 = bg.quantize(2, method=2)
    bg1.save(output_file, compresssion="bmp_rle")
"""


def export_svg_to_png(input_file, output_file=None):
    global inkscape_shell
    if inkscape_shell is None:
        inkscape_shell = InkscapeShell()
    inkscape_shell.export_svg_to_png(input_file, output_file)
    # assert(input_file.endswith('.svg'))
    # if output_file is None:
    #     output_file = input_file[:-3] + 'png'
    # args = [
    #     'inkscape',
    #     '-z',
    #     '-f', input_file,
    #     '-e', output_file,
    #     '--export-dpi=300',
    #     '--export-area-page',
    #     ]
    # timed_check_call(args, cwd=svg_dir, timeout=15)


def export_svg_to_bmp(svg_file, bmp_file=None):
    assert svg_file.endswith('.svg')
    if bmp_file is None:
        bmp_file = svg_file[:-3] + 'bmp'
    with tempfile.NamedTemporaryFile(
        prefix='',
        suffix='.png',
        delete=False
    ) as temp_file:
        png_file = temp_file.name
    try:
        export_svg_to_png(svg_file, png_file)
        convert_png_to_bmp(png_file, bmp_file)
    finally:
        if isfile(png_file):
            try:
                remove(png_file)
            except OSError:
                print('cannot remove temporary file:', png_file)
                traceback.print_exc(file=stdout)
